from setuptools import setup

setup(name='ab_biga',
      version='1.0',
      description='Gaussian distrbutions',
      packages=['ab_biga'],
      author='Abrham Gebregiorgis',
      author_email="abrhamgg@gmail.com",
      zip_safe=False)
